<?php

namespace Drupal\monarch_vue_field\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\TypedData\MapDataDefinition;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldStorageDefinitionInterface;

/**
 * Defines the 'Vue App' field type.
 *
 * @FieldType(
 *   id = "vue_app",
 *   label = @Translation("Vue App"),
 *   category = @Translation("Custom"),
 *   default_widget = "vue_app_default",
 *   default_formatter = "vue_app_default",
 *   cardinality = 1
 * )
 */
class VueAppItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    return empty($this->get('data')->getValue());
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['data'] = MapDataDefinition::create()
      ->setRequired(FALSE)
      ->setLabel(t('Vue App'));

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return [
      'columns' => [
        'data' => [
          'type' => 'blob',
          'size' => 'big',
          'serialize' => TRUE,
          'description' => 'Vue App Data',
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function generateSampleValue(FieldDefinitionInterface $field_definition) {
    return [
      'data' => [],
    ];
  }

}
